@@ -1,16 +1,12 @@
-# -*- coding: utf-8 -*-
 # SPDX-License-Identifier: ISC
 # Copyright (c) Justus Winter <4winter@informatik.uni-hamburg.de>
 
-from __future__ import print_function, absolute_import, unicode_literals
-
 import pkg_resources
 
-
 RAISEIT = object()
 
 
-class FilterRegistry(object):
+class FilterRegistry:
     """
     The FilterRegistry is responsible for returning
     filters by key.
@@ -18,6 +14,7 @@ class FilterRegistry(object):
     To avoid any circular dependencies, the registry loads
     the Filters lazily
     """
+
     def __init__(self, filters):
         self._filteriterator = filters
 
@@ -56,9 +53,9 @@ class FilterRegistry(object):
 
 all_filters = FilterRegistry(pkg_resources.iter_entry_points('afew.filter'))
 
-def register_filter (klass):
+
+def register_filter(klass):
     '''Decorator function for registering a class as a filter.'''
 
     all_filters[klass.__name__] = klass
     return klass
-
