@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 # SPDX-License-Identifier: ISC
 # Copyright (c) Justus Winter <4winter@informatik.uni-hamburg.de>
 
-from __future__ import print_function, absolute_import, unicode_literals
-
-from .HeaderMatchingFilter import HeaderMatchingFilter
+from afew.filters.HeaderMatchingFilter import HeaderMatchingFilter
 
 
 class SpamFilter(HeaderMatchingFilter):
@@ -17,4 +14,4 @@ class SpamFilter(HeaderMatchingFilter):
             # this is for backward-compatibility
             tags = '+' + spam_tag
         kwargs['tags'] = [tags]
-        super(SpamFilter, self).__init__(database, **kwargs)
+        super().__init__(database, **kwargs)
